@@ -14,8 +14,8 @@ jeffreys <- function(x1, x2, check = FALSE)
     if (is.data.frame(x2)) x2 <- x2[, 1]
     if (is.matrix(x1)) x1 <- drop(x1)
     if (is.matrix(x2)) x2 <- drop(x2)
-    return(jeffreyspar(mean(x1),var(x1),mean(x2),var(x2),check=FALSE))
+    return(jeffreyspar(mean(x1),var(x1),mean(x2),var(x2),check=check))
   } else {
-    return(jeffreyspar(colMeans(x1),var(x1),colMeans(x2),var(x2),check=FALSE))
+    return(jeffreyspar(colMeans(x1),var(x1),colMeans(x2),var(x2),check=check))
   }
 }
